CredentialHandlerExt

Trait CredentialHandlerExt 

pub trait CredentialHandlerExt:
    Send
    + Sync
    + 'static {
    // Required method
    fn get_credential_internal<'life0, 'async_trait>(
        &'life0 self,
        request: GetCredentialRequest,
    ) -> Pin<Box<dyn Future<Output = Result<Credential>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}

Required Methods

fn get_credential_internal<'life0, 'async_trait>( &'life0 self, request: GetCredentialRequest, ) -> Pin<Box<dyn Future<Output = Result<Credential>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get a credential without checking permissions.

This is used internally when access to a resource is already checked and we need to create internal stores or vended credentials for the resource.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors