ShareHandler

Trait ShareHandler 

pub trait ShareHandler<Cx = RequestContext>:
    Send
    + Sync
    + 'static {
    // Required methods
    fn list_shares<'life0, 'async_trait>(
        &'life0 self,
        request: ListSharesRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<ListSharesResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn create_share<'life0, 'async_trait>(
        &'life0 self,
        request: CreateShareRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn get_share<'life0, 'async_trait>(
        &'life0 self,
        request: GetShareRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn update_share<'life0, 'async_trait>(
        &'life0 self,
        request: UpdateShareRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn delete_share<'life0, 'async_trait>(
        &'life0 self,
        request: DeleteShareRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn get_permissions<'life0, 'async_trait>(
        &'life0 self,
        request: GetPermissionsRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<GetPermissionsResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn update_permissions<'life0, 'async_trait>(
        &'life0 self,
        request: UpdatePermissionsRequest,
        context: Cx,
    ) -> Pin<Box<dyn Future<Output = Result<UpdatePermissionsResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}

Required Methods

fn list_shares<'life0, 'async_trait>( &'life0 self, request: ListSharesRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<ListSharesResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

List shares.

fn create_share<'life0, 'async_trait>( &'life0 self, request: CreateShareRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Create a new share.

fn get_share<'life0, 'async_trait>( &'life0 self, request: GetShareRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get a share by name.

fn update_share<'life0, 'async_trait>( &'life0 self, request: UpdateShareRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<Share>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Update a share.

fn delete_share<'life0, 'async_trait>( &'life0 self, request: DeleteShareRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Deletes a share.

fn get_permissions<'life0, 'async_trait>( &'life0 self, request: GetPermissionsRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<GetPermissionsResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Gets the permissions for a data share from the metastore.

fn update_permissions<'life0, 'async_trait>( &'life0 self, request: UpdatePermissionsRequest, context: Cx, ) -> Pin<Box<dyn Future<Output = Result<UpdatePermissionsResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Updates the permissions for a data share in the metastore.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors