InMemoryResourceStore

Struct InMemoryResourceStore 

pub struct InMemoryResourceStore { /* private fields */ }
An in-memory implementation of a resource store.

Not intended for production use, but useful for testing and development. Like the durable backends, credential secret fields are sealed inline on the object row (see ManagedObjectStore); there is no separate secret store.

Implementations