pub struct ConstantPolicy { /* private fields */ }Expand description
Policy that always returns a constant decision.
This policy is mainly useful for testing and development, or servers that do not require authorization checks - e.g. when deployed in a trusted environment.
Implementations
Sourceimpl ConstantPolicy
impl ConstantPolicy
Sourcepub fn new(decision: Decision) -> Self
pub fn new(decision: Decision) -> Self
Create a new instance of ConstantPolicy.