StorageLocationUrl

Struct StorageLocationUrl 

pub struct StorageLocationUrl { /* private fields */ }
A URL representing a storage location.

This struct provides a cerntalized place to parse various URLs into more specific service references along with the semantic information that can be extracted from the URL.

Implementations

Source

impl StorageLocationUrl

pub fn try_new(url: Url) -> Result<Self>

pub fn parse(url: impl AsRef<str>) -> Result<Self>

pub fn raw(&self) -> &Url

pub fn location(&self) -> &Url

pub fn store_url(&self) -> &Url

pub fn scheme(&self) -> &StorageLocationScheme

pub fn bucket_and_prefix(&self) -> Result<(String, String)>

Returns (bucket_or_container, object_prefix) extracted from the URL.

  • S3: s3://bucket/prefix/path("bucket", "prefix/path")
  • Azure HTTPS: https://account.blob.core.windows.net/container/path("container", "path")
  • Azurite HTTP: http://localhost:10000/account/container/path("container", "path")
  • Azurite custom scheme: azurite://container/path("container", "path")
pub fn azure_account(&self) -> Option<String>

Returns the Azure storage account name parsed from the URL, if present.

  • HTTPS: https://account.blob.core.windows.net/…Some("account")
  • ABFSS: abfss://container@account.dfs.core.windows.net/…Some("account")
  • Azurite HTTP: http://localhost:10000/account/container/pathSome("account")
  • Azurite custom: azurite://container/pathNone (no account concept)