pub trait ModelVersionHandler<Cx = RequestContext>:
Send
+ Sync
+ 'static {
// Required methods
fn list_model_versions<'life0, 'async_trait>(
&'life0 self,
request: ListModelVersionsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListModelVersionsResponse>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn create_model_version<'life0, 'async_trait>(
&'life0 self,
request: CreateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_model_version<'life0, 'async_trait>(
&'life0 self,
request: GetModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn update_model_version<'life0, 'async_trait>(
&'life0 self,
request: UpdateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn delete_model_version<'life0, 'async_trait>(
&'life0 self,
request: DeleteModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn finalize_model_version<'life0, 'async_trait>(
&'life0 self,
request: FinalizeModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn list_model_versions<'life0, 'async_trait>(
&'life0 self,
request: ListModelVersionsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListModelVersionsResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_model_versions<'life0, 'async_trait>(
&'life0 self,
request: ListModelVersionsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListModelVersionsResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List model versions
List the model versions of the specified registered model. If the caller is the metastore admin, all model versions are returned. Otherwise, the caller must have the appropriate privileges on the parent model.
Sourcefn create_model_version<'life0, 'async_trait>(
&'life0 self,
request: CreateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_model_version<'life0, 'async_trait>(
&'life0 self,
request: CreateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Create a model version
Creates a new model version in PENDING_REGISTRATION status. The server assigns the version number and a storage location for the artifacts. The caller must be a metastore admin or the owner of the parent registered model.
Sourcefn get_model_version<'life0, 'async_trait>(
&'life0 self,
request: GetModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_model_version<'life0, 'async_trait>(
&'life0 self,
request: GetModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a model version
Gets a model version by its parent model name and version number.
Sourcefn update_model_version<'life0, 'async_trait>(
&'life0 self,
request: UpdateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn update_model_version<'life0, 'async_trait>(
&'life0 self,
request: UpdateModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Update a model version
Updates the model version that matches the supplied name and version.
Sourcefn delete_model_version<'life0, 'async_trait>(
&'life0 self,
request: DeleteModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_model_version<'life0, 'async_trait>(
&'life0 self,
request: DeleteModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Delete a model version
Deletes the model version that matches the supplied name and version. For the deletion to succeed, the caller must be the owner of the parent registered model.
Sourcefn finalize_model_version<'life0, 'async_trait>(
&'life0 self,
request: FinalizeModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn finalize_model_version<'life0, 'async_trait>(
&'life0 self,
request: FinalizeModelVersionRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ModelVersion>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Finalize a model version
Transitions a model version to READY once all artifacts have been written to its storage location.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".