pub trait RegisteredModelHandler<Cx = RequestContext>:
Send
+ Sync
+ 'static {
// Required methods
fn list_registered_models<'life0, 'async_trait>(
&'life0 self,
request: ListRegisteredModelsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListRegisteredModelsResponse>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn create_registered_model<'life0, 'async_trait>(
&'life0 self,
request: CreateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_registered_model<'life0, 'async_trait>(
&'life0 self,
request: GetRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn update_registered_model<'life0, 'async_trait>(
&'life0 self,
request: UpdateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn delete_registered_model<'life0, 'async_trait>(
&'life0 self,
request: DeleteRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn list_registered_models<'life0, 'async_trait>(
&'life0 self,
request: ListRegisteredModelsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListRegisteredModelsResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn list_registered_models<'life0, 'async_trait>(
&'life0 self,
request: ListRegisteredModelsRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<ListRegisteredModelsResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
List registered models
List registered models within the specified parent catalog and schema. If the caller is the metastore admin, all registered models are returned in the response. Otherwise, the caller must have USE_CATALOG on the parent catalog and USE_SCHEMA on the parent schema, and the model must either be owned by the caller or the caller must have a privilege on the model.
Sourcefn create_registered_model<'life0, 'async_trait>(
&'life0 self,
request: CreateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn create_registered_model<'life0, 'async_trait>(
&'life0 self,
request: CreateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Create a registered model
Creates a new registered model. The caller must be a metastore admin or have the CREATE_MODEL privilege on the parent catalog and schema.
Sourcefn get_registered_model<'life0, 'async_trait>(
&'life0 self,
request: GetRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_registered_model<'life0, 'async_trait>(
&'life0 self,
request: GetRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a registered model
Gets a registered model from within a parent catalog and schema. For the fetch to succeed, the caller must be a metastore admin, the owner of the registered model, or have a privilege on the registered model.
Sourcefn update_registered_model<'life0, 'async_trait>(
&'life0 self,
request: UpdateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn update_registered_model<'life0, 'async_trait>(
&'life0 self,
request: UpdateRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<RegisteredModel>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Update a registered model
Updates the registered model that matches the supplied name.
Sourcefn delete_registered_model<'life0, 'async_trait>(
&'life0 self,
request: DeleteRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn delete_registered_model<'life0, 'async_trait>(
&'life0 self,
request: DeleteRegisteredModelRequest,
context: Cx,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Delete a registered model
Deletes the registered model that matches the supplied name. For the deletion to succeed, the caller must be the owner of the registered model.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".