pub struct InMemoryResourceStore { /* private fields */ }Expand description
An in-memory implementation of a resource store.
Not intended for production use, but useful for testing and development. Like
the durable backends, credential secret fields are sealed inline on the
object row (see ManagedObjectStore); there is no separate secret store.
Implementations
Sourceimpl InMemoryResourceStore
impl InMemoryResourceStore
pub fn new(encryptor: EnvelopeEncryptor) -> Self