pub async fn process_resources<T: Policy<Cx> + Sized, Cx: Send + Sync + 'static, R: ResourceExt + Send>(
handler: &T,
context: &Cx,
permission: &Permission,
resources: &mut Vec<R>,
) -> Result<()>Expand description
Checks if the context has the given permission for each resource, and retains only those that receive an allow decision.